
'''
This file is automatically generated by setup.py, So don't edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.12.5.post1',
    'branch_nick': '(detached',
    'revision_id': 'bdd78ad4edd77b0e002a63544d2dc8dc2d710a80',
    'revno': 5284
}
